@@ -55,9 +55,9 @@ def function_rl(field):
         digit_list = re.findall("{__RL(.+?)}", field)
         # 获取位数列表
         for i in digit_list:
-            random_number = create_random_letters(int(i))
+            random_letters = create_random_letters(int(i))
             # 调用生成随机数字的方法
-            field = field.replace("{__RL" + i + "}", random_number)
+            field = field.replace("{__RL" + i + "}", random_letters)
     else:
         pass
 
@@ -128,6 +128,29 @@ def function_sql(field, mysql_result_list):
     # 返回替换后的字段
 
 
+def function_pgsql(field, pgsql_result_list):
+    """
+    替换PgSQL查询结果的方法
+    :param field: 第一个参数是yaml文件里面定义的字段
+    :param pgsql_result_list: 第二个参数是PgSQL查询结果列表
+    :return:
+    """
+
+    if "{__PGSQL" in field:
+        pgsql_index_list = re.findall("{__PGSQL(.+?)}", field)
+        # 获取索引列表
+        for i in pgsql_index_list:
+            pgsql_value = pgsql_result_list[int(i)]
+            if type(pgsql_value) != str:
+                pgsql_value = str(pgsql_value)
+            field = field.replace("{__PGSQL" + i + "}", pgsql_value)
+    else:
+        pass
+
+    return field
+    # 返回替换后的字段
+
+
 def function_mongo(field, mongo_result_list):
     """
     替换Mongo查询结果的方法
@@ -149,3 +172,26 @@ def function_mongo(field, mongo_result_list):
 
     return field
     # 返回替换后的字段
+
+
+def function_redis(field, redis_result_list):
+    """
+    替换Redis查询结果的方法
+    :param field: 第一个参数是yaml文件里面定义的字段
+    :param redis_result_list: 第二个参数是Redis查询结果列表
+    :return:
+    """
+
+    if "{__REDIS" in field:
+        redis_index_list = re.findall("{__REDIS(.+?)}", field)
+        # 获取索引列表
+        for i in redis_index_list:
+            redis_value = redis_result_list[int(i)]
+            if type(redis_value) != str:
+                redis_value = str(redis_value)
+            field = field.replace("{__REDIS" + i + "}", redis_value)
+    else:
+        pass
+
+    return field
+    # 返回替换后的字段
